// module pour les fonctions de base d'accès aux API Openweathermap

export const API_KEY="<votre clé d'API>";
const geoCodingAPIUrl = `https://api.openweathermap.org/geo/1.0/direct?limit=5&appid=${API_KEY}&q=`; // API de geocodage openWeather
const currentWeatherAPIUrl = `https://api.openweathermap.org/data/2.5/weather?appid=${API_KEY}&lang=fr&units=metric`;  

/**
 * Recherche avec l'API de géocodage les localisation d'un lieu donné
 * @param {string} locationName nom du lieu à rechercher
 * @returns un tableau d'objets location dont le nom correspond (contient) locationName
 */
export async function getLocation(locationName) {
    let httpResponse = await fetch(geoCodingAPIUrl + locationName);

    if (httpResponse.ok) {  // code de réponse HTTP 200 -> 299
        console.log("getLocation en-têtes de réponse reçus");
         let responseBody = await httpResponse.json();
         console.log("get Location données reçues");
         let locations = [];
         for (let location of responseBody) {
            if (location.local_names) {
                // l'objet locations possède le nom du lieu dans plusieurs langues
                // inutile de s'en encombrer dans les résultats
                delete location.local_names;
            }
            locations.push(location);
         }
         return locations;
    }
    else {  // code réponse HTTP pas dans plage 200 -> 299
        console.error(`getLocation : réponse incorrecte status code ${httpResponse.status} ${httpResponse.statusText}`);
        return [];
    }
    
}

/**
 * Récupère les conditions météorologiques en un lieu donné
 * @param {Location} location le lieu pour lequel la météo est consultée
 * @returns un objet réprésentant les conditions météo actuelles au lieu défini par location
 * cet objet a la structure suivante
 * {
 *     temperature : la température en degrés celsius  (number)
 *     description : une description textuelle des conditions météo (string)
 *     iconURL : l'URL de l'icon open weather map qui correspond  aux conditions météo (string)
 *     day : la date à laquelle l'observation météorologique a été effectuée (string de la formm 16 Fev. 2025)
 *     time : l'heure à laquelle l'observation météorologique a été effectuée (string de la formm HH:MM:SS)
 * }
 * 
 */
export async function getCurrentWeather(location) {
    let httpResponse = await fetch(currentWeatherAPIUrl+`&lat=${location.lat}&lon=${location.lon}`);
    if (httpResponse.ok) {
        let responseBody = await httpResponse.json();
        // Récupérer les données de température et de description du temps
        const timestamp = responseBody.dt * 1000; // dt est en secondes, on mutiplie par 1000 pour avoir des ms
        const date = new Date(timestamp);
        const dateString = date.toLocaleDateString("fr-FR", {
            day: "numeric",
            month: "short",
            year: "numeric",
        });
        const timeString = date.toLocaleTimeString("fr-FR", {
            hour: "2-digit",
            minute: "2-digit",
            second: "2-digit",
        });

        return {
            temperature: responseBody.main.temp,
            description: responseBody.weather[0].description,
            iconURL: "https://openweathermap.org/img/wn/" + responseBody.weather[0].icon + ".png",
            day: dateString,
            time: timeString,
        };
    } else {
        // pour le moment on affiche un simple message sur la console
        console.error(`getCurrentWeather : réponse incorrecte status code ${httpResponse.status} ${httpResponse.statusText}`);
        return null;
    }
}